@@ -98,25 +98,29 @@ class Provisioner(_utils.GetNodeMixin):
 
         if candidates:
             nodes = [self._get_node(node) for node in candidates]
-            filters = [
-                _scheduler.NodeTypeFilter(resource_class, conductor_group),
-            ]
         else:
+            kwargs = {}
+            if conductor_group:
+                kwargs['conductor_group'] = conductor_group
             nodes = list(self.connection.baremetal.nodes(
+                associated=False,
+                provision_state='available',
+                maintenance=False,
                 resource_class=resource_class,
-                conductor_group=conductor_group,
-                details=True))
+                details=True,
+                **kwargs))
             if not nodes:
                 raise exceptions.NodesNotFound(resource_class, conductor_group)
             # Ensure parallel executions don't try nodes in the same sequence
             random.shuffle(nodes)
-            # No need to filter by resource_class and conductor_group any more
-            filters = []
 
         LOG.debug('Candidate nodes: %s', nodes)
 
-        filters.append(_scheduler.CapabilitiesFilter(capabilities))
-        filters.append(_scheduler.TraitsFilter(traits))
+        filters = [
+            _scheduler.NodeTypeFilter(resource_class, conductor_group),
+            _scheduler.CapabilitiesFilter(capabilities),
+            _scheduler.TraitsFilter(traits),
+        ]
         if predicate is not None:
             filters.append(_scheduler.CustomPredicateFilter(predicate))
 
@@ -419,6 +423,8 @@ class Provisioner(_utils.GetNodeMixin):
 
         :param instance_id: hostname, UUID or node name.
         :return: :py:class:`metalsmith.Instance` object.
+        :raises: :py:class:`metalsmith.exceptions.InvalidInstance`
+            if the instance is not a valid instance.
         """
         return self.show_instances([instance_id])[0]
 
@@ -431,14 +437,25 @@ class Provisioner(_utils.GetNodeMixin):
         :param instances: list of hostnames, UUIDs or node names.
         :return: list of :py:class:`metalsmith.Instance` objects in the same
             order as ``instances``.
+        :raises: :py:class:`metalsmith.exceptions.InvalidInstance`
+            if one of the instances are not valid instances.
         """
         with self._cache_node_list_for_lookup():
-            return [
+            result = [
                 _instance.Instance(
                     self.connection,
                     self._get_node(inst, accept_hostname=True))
                 for inst in instances
             ]
+        # NOTE(dtantsur): do not accept node names as valid instances if they
+        # are not deployed or being deployed.
+        missing = [inst for (res, inst) in zip(result, instances)
+                   if res.state == _instance.InstanceState.UNKNOWN]
+        if missing:
+            raise exceptions.InvalidInstance(
+                "Node(s)/instance(s) %s are not valid instances"
+                % ', '.join(map(str, missing)))
+        return result
 
     def list_instances(self):
         """List instances deployed by metalsmith.
@@ -449,5 +466,5 @@ class Provisioner(_utils.GetNodeMixin):
         instances = [i for i in
                      (_instance.Instance(self.connection, node)
                       for node in nodes)
-                     if i._is_deployed_by_metalsmith]
+                     if i.state != _instance.InstanceState.UNKNOWN]
         return instances
